@@ -19,27 +19,25 @@
 
 /**
  * SECTION:element-gdkpixbufoverlay
+ * @title: gdkpixbufoverlay
  *
- * The gdkpixbufoverlay element overlays an image loaded from file onto
- * a video stream.
+ * The gdkpixbufoverlay element overlays a provided GdkPixbuf or an image
+ * loaded from file onto a video stream.
  *
  * Changing the positioning or overlay width and height properties at runtime
  * is supported, but it might be prudent to to protect the property setting
  * code with GST_BASE_TRANSFORM_LOCK and GST_BASE_TRANSFORM_UNLOCK, as
  * g_object_set() is not atomic for multiple properties passed in one go.
  *
- * Changing the image at runtime is currently not supported.
+ * Changing the image at runtime is supported.
  *
- * Negative offsets are also not yet supported.
- *
- * <refsect2>
- * <title>Example launch line</title>
+ * ## Example launch line
  * |[
  * gst-launch-1.0 -v videotestsrc ! gdkpixbufoverlay location=image.png ! autovideosink
  * ]|
  * Overlays the image in image.png onto the test video picture produced by
  * videotestsrc.
- * </refsect2>
+ *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -49,6 +47,7 @@
 #include <gst/gst.h>
 #include "gstgdkpixbufoverlay.h"
 
+#include "gstgdkpixbufelements.h"
 #include <gst/video/gstvideometa.h>
 
 GST_DEBUG_CATEGORY_STATIC (gdkpixbufoverlay_debug);
@@ -93,13 +92,6 @@ enum
   PROP_ALPHA
 };
 
-#define VIDEO_FORMATS "{ RGBx, RGB, BGR, BGRx, xRGB, xBGR, " \
-    "RGBA, BGRA, ARGB, ABGR, I420, YV12, AYUV, YUY2, UYVY, " \
-    "v308, v210, v216, Y41B, Y42B, Y444, YVYU, NV12, NV21, UYVP, " \
-    "RGB16, BGR16, RGB15, BGR15, UYVP, A420, YUV9, YVU9, " \
-    "IYU1, ARGB64, AYUV64, r210, I420_10LE, I420_10BE, " \
-    "GRAY8, GRAY16_BE, GRAY16_LE }"
-
 /* FIXME 2.0: change to absolute positioning */
 #define DEFAULT_POSITIONING_MODE \
     GST_GDK_PIXBUF_POSITIONING_PIXELS_RELATIVE_TO_EDGES
@@ -107,17 +99,22 @@ enum
 static GstStaticPadTemplate sink_template = GST_STATIC_PAD_TEMPLATE ("sink",
     GST_PAD_SINK,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS (GST_VIDEO_CAPS_MAKE (VIDEO_FORMATS))
+    GST_STATIC_CAPS (GST_VIDEO_CAPS_MAKE
+        (GST_VIDEO_OVERLAY_COMPOSITION_BLEND_FORMATS))
     );
 
 static GstStaticPadTemplate src_template = GST_STATIC_PAD_TEMPLATE ("src",
     GST_PAD_SRC,
     GST_PAD_ALWAYS,
-    GST_STATIC_CAPS (GST_VIDEO_CAPS_MAKE (VIDEO_FORMATS))
+    GST_STATIC_CAPS (GST_VIDEO_CAPS_MAKE
+        (GST_VIDEO_OVERLAY_COMPOSITION_BLEND_FORMATS))
     );
 
 G_DEFINE_TYPE (GstGdkPixbufOverlay, gst_gdk_pixbuf_overlay,
     GST_TYPE_VIDEO_FILTER);
+GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (gdkpixbufoverlay, "gdkpixbufoverlay",
+    GST_RANK_NONE, GST_TYPE_GDK_PIXBUF_OVERLAY,
+    gdk_pixbuf_element_init (plugin));
 
 #define GST_TYPE_GDK_PIXBUF_POSITIONING_MODE \
     (gst_gdk_pixbuf_positioning_mode_get_type())
@@ -292,6 +289,8 @@ gst_gdk_pixbuf_overlay_class_init (GstGdkPixbufOverlayClass * klass)
       "Tim-Philipp Müller <tim centricular net>");
   GST_DEBUG_CATEGORY_INIT (gdkpixbufoverlay_debug, "gdkpixbufoverlay", 0,
       "debug category for gdkpixbufoverlay element");
+
+  gst_type_mark_as_plugin_api (GST_TYPE_GDK_PIXBUF_POSITIONING_MODE, 0);
 }
 
 static void
